@@ -35,7 +35,7 @@ NO_LABEL_WIDGETS = ("button", "toolbutton", "frame", "label", "check")
 class Q2Form:
     def __init__(self, title=""):
         super().__init__()
-        self.title = title
+        self.title = title.strip().split("\n")[0][:50]
         self.name = title
         self.form_stack = []
         self.style_sheet = ""
@@ -401,6 +401,10 @@ class Q2Form:
         self.refresh(True)
         self.set_grid_index(curr_row)
 
+    def is_grid_updateable(self):
+        table_name = self.model.get_table_name()
+        return table_name != "" and " " not in table_name
+
     def build_grid_view_auto_form(self):
         # Define layout
         if self.model.records:
@@ -1207,11 +1211,12 @@ class Q2FormWindow:
             eof_disabled=1,
         )
 
-        actions.add_action(
-            text=q2app.ACTION_TOOLS_TEXT + "|" + q2app.ACTION_TOOLS_IMPORT_TEXT,
-            worker=self.q2_form.grid_data_import,
-            icon=q2app.ACTION_TOOLS_IMPORT_ICON,
-        )
+        if self.q2_form.is_grid_updateable():
+            actions.add_action(
+                text=q2app.ACTION_TOOLS_TEXT + "|" + q2app.ACTION_TOOLS_IMPORT_TEXT,
+                worker=self.q2_form.grid_data_import,
+                icon=q2app.ACTION_TOOLS_IMPORT_ICON,
+            )
         actions.add_action(
             text=q2app.ACTION_TOOLS_TEXT + "|-",
         )
@@ -1251,7 +1256,7 @@ class Q2FormWindow:
             actions.add_action(
                 text=q2app.ACTION_CLOSE_TEXT, worker=self.close, icon=q2app.ACTION_CLOSE_ICON, tag="orange"
             )
-
+        self.q2_form.grid_navigation_actions_hook(actions)
         return actions
 
     def move_grid_index(self, direction=None):
@@ -1320,6 +1325,9 @@ class Q2FormWindow:
         self.q2_form.refresh_children()
         self.move_grid_index(1)
 
+    def grid_navigation_actions_hook(self, actions):
+        pass
+
     def build_form(self, controls=[]):
         frame_stack = [self]
         tmp_frame = None
@@ -1344,8 +1352,8 @@ class Q2FormWindow:
                 label2add, widget2add = self.widget(meta)
 
                 if current_frame.frame_mode == "f":  # form layout
-                    if label2add is not None:
-                        label2add.set_content_margins(0, int(q2app.q2_app.get_char_height() / 4), 2, 0)
+                    # if label2add is not None:
+                    #     label2add.set_content_margins(10, int(q2app.q2_app.get_char_height() / 4), 2, 0)
                     if hasattr(widget2add, "frame_mode") and not meta.get("relation"):
                         # add any frame into form frame
                         if label2add is None:
